@@ -775,6 +775,8 @@ protected:
 	BayonneTranslator *next;
 	const char *id;
 
+	static const char *getToken(BayonneSession *s, Line *l, unsigned *idx);
+
 public:
 	/**
 	 * Create a translator instance for a specific language identifier.
@@ -800,7 +802,7 @@ public:
 	 * @param iso module name to load.
 	 * @return true if successful.
 	 */
-	static bool load(const char *prefix, const char *name);
+	static bool loadTranslator(const char *prefix, const char *name);
 
 	/**
 	 * Translate a simple set of digits to spoken speech.
@@ -918,7 +920,7 @@ public:
          * @return error message or NULL if okay
 	 * @param timeslot session to process a command from.
          */
-	virtual const char *speak(BayonneSession *session);
+	virtual const char *speak(BayonneSession *session, Line *line = NULL);
 };
 
 /**
@@ -1173,7 +1175,7 @@ public:
 	 * @param driver name to load.
 	 * @return NULL or pointer to loaded driver.
 	 */
-	static BayonneDriver *load(const char *prefix, const char *id);
+	static BayonneDriver *loadDriver(const char *prefix, const char *id);
 
 	/**
 	 * Get list of driver names into string array.
