@@ -139,7 +139,7 @@ void BayonneDriver::add(BayonneSession *session)
 	}		
 }
 
-BayonneDriver *BayonneDriver::load(const char *prefix, const char *id)
+BayonneDriver *BayonneDriver::loadDriver(const char *prefix, const char *id)
 {
 	DSO *dso;
 	BayonneDriver *d;
