@@ -131,6 +131,26 @@ const char *Checks::chkDialer(Line *line, ScriptImage *img)
 	return NULL;
 }
 
+const char *Checks::chkTonegen(Line *line, ScriptImage *img)
+{
+	const char *cp;
+
+	if(getMember(line))
+		return "tone has no members";
+
+	if(!useKeywords(line, "=level=freq1=freq2=frequency=duration"))
+		return "unknown keyword for tone";
+
+	cp = findKeyword(line, "frequency");
+	if(!cp)
+		cp = findKeyword(line, "freq1");
+
+	if(!cp)
+		return "no tone frequency specified";
+
+	return NULL;
+}	
+
 const char *Checks::chkTone(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
