@@ -458,6 +458,43 @@ bool Methods::scrMF(void)
 }
 
 
+bool Methods::scrTonegen(void)
+{
+	Audio::Level level = 26000;
+	const char *cp = getKeyword("level");
+	const char *f1, *f2;
+
+	state.timeout = getTimeoutKeyword("duration");
+	state.tone.exiting = false;
+
+	if(cp)
+		level = atoi(cp);
+
+	if(audio.tone)
+	{
+		delete audio.tone;
+		audio.tone = NULL;
+	}
+
+	cp = getKeyword("frequency");
+	f1 = getKeyword("freq1");
+	f2 = getKeyword("freq2");
+
+	if(!f1)
+		f1 = "0";
+
+	if(!f2)
+		f2 = "0";
+
+	if(cp)
+		audio.tone = new AudioTone(atoi(cp), level, getToneFraming());
+	else
+		audio.tone = new AudioTone(atoi(f1), atoi(f2), level, level, getToneFraming());
+
+	setState(STATE_TONE);	
+	return false;
+}
+
 bool Methods::scrTone(void)
 {
 	Line *line = getLine();
