@@ -57,6 +57,8 @@ ScriptRuntime()
                         (Check)&Checks::chkTone},
                 {"sit", false, (Method)&Methods::scrTone,
                         (Check)&Checks::chkTone},
+		{"tone", false, (Method)&Methods::scrTonegen,
+			(Check)&Checks::chkTonegen},
                 {"callwait", false, (Method)&Methods::scrTone,
                         (Check)&Checks::chkTone},
                 {"callback", false, (Method)&Methods::scrTone,
