@@ -87,7 +87,7 @@ static void version(void)
 
 static void loadStack(const char *id)
 {
-	BayonneDriver *d = BayonneDriver::load(keypaths.getLast("drivers"), id);
+	BayonneDriver *d = BayonneDriver::loadDriver(keypaths.getLast("drivers"), id);
 
 	if(!d)
 	{
@@ -109,7 +109,7 @@ static void loading(void)
 	Libexec::allocate();
 #endif
 
-	driver = BayonneDriver::load(keypaths.getLast("drivers"), dname);
+	driver = BayonneDriver::loadDriver(keypaths.getLast("drivers"), dname);
 	if(!driver)
 		stop(-1);
 
