@@ -169,6 +169,7 @@ public:
 	bool scrPrompt(void);
 	bool scrBuild(void);
 	bool scrTone(void);
+	bool scrTonegen(void);
 	bool scrDTMF(void);
 	bool scrMF(void);
 	bool scrCancel(void);
@@ -185,6 +186,7 @@ public:
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+	const char *chkTonegen(Line *line, ScriptImage *img);
 	const char *chkRegister(Line *line, ScriptImage *img);
 	const char *chkAssign(Line *line, ScriptImage *img);
 	const char *chkSelect(Line *line, ScriptImage *img);
